# Copyright (c) 2000
#   Peter Johnson <wakefield@users.sourceforge.net>.  All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. Neither the name of the author nor the names of any co-contributors
#    may be used to endorse or promote products derived from this software
#    without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL Peter Johnson OR
# OTHER CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# $Id: alumni.sql,v 1.4 2001/01/11 08:08:37 wakefield Exp $

# MySQL table declarations for ALUMNI CGI database.

#
# Table structure for table 'AdminLog'
#
CREATE TABLE AdminLog (
  AdminLogID int(11) DEFAULT '0' NOT NULL auto_increment,
  AdminName varchar(10) DEFAULT '' NOT NULL,
  Action varchar(20) DEFAULT '' NOT NULL,
  AlumID int(11),
  TimeStamp timestamp(14),
  PRIMARY KEY (AdminLogID),
  KEY AdminName (AdminName),
  KEY Action (Action),
  KEY TimeStamp (TimeStamp)
);

#
# Table structure for table 'Alumni'
#
CREATE TABLE Alumni (
  AlumID int(10) unsigned DEFAULT '0' NOT NULL auto_increment,
  Approved tinyint(1) unsigned DEFAULT '0' NOT NULL,
  Name_First varchar(100) DEFAULT '' NOT NULL,
  Name_Middle varchar(100),
  Name_Last varchar(100) DEFAULT '' NOT NULL,
  Name_Nick varchar(100),
  School tinyint(1) unsigned DEFAULT '0' NOT NULL,
  Year smallint(4) unsigned DEFAULT '0' NOT NULL,
  Public_EMail tinyint(1) unsigned DEFAULT '0' NOT NULL,
  EMail varchar(100),
  Public_Occupation tinyint(1) unsigned DEFAULT '0' NOT NULL,
  Occupation tinyint(1) unsigned DEFAULT '0' NOT NULL,
  Occupation_Where varchar(200),
  Occupation_What varchar(200),
  Public_Address tinyint(1) unsigned DEFAULT '0' NOT NULL,
  Address_1 varchar(200),
  Address_2 varchar(200),
  Public_Phone tinyint(1) unsigned DEFAULT '0' NOT NULL,
  Phone varchar(30),
  Password varchar(100) DEFAULT '' NOT NULL,
  PRIMARY KEY (AlumID),
  KEY Approved (Approved),
  KEY Name_First (Name_First),
  KEY Name_Last (Name_Last),
  KEY School (School),
  KEY Year (Year),
  KEY Public_Occupation (Public_Occupation),
  KEY Occupation (Occupation)
);

#
# Table structure for table 'ClassContacts'
#
CREATE TABLE ClassContacts (
  ClassContactID int(10) unsigned DEFAULT '0' NOT NULL auto_increment,
  AlumID int(10) unsigned DEFAULT '0' NOT NULL,
  School tinyint(1) unsigned DEFAULT '0' NOT NULL,
  Year smallint(4) unsigned DEFAULT '0' NOT NULL,
  Name varchar(100) DEFAULT '' NOT NULL,
  Phone_Type_1 varchar(10),
  Phone_1 varchar(50),
  Phone_Type_2 varchar(10),
  Phone_2 varchar(50),
  Phone_Type_3 varchar(10),
  Phone_3 varchar(50),
  Address_1 varchar(200),
  Address_2 varchar(200),
  Address_3 varchar(200),
  EMail varchar(100),
  URL varchar(200),
  ReunionInfo text,
  LastUpdated timestamp(14),
  PRIMARY KEY (ClassContactID),
  KEY AlumID (AlumID),
  KEY School (School),
  KEY Year (Year),
  KEY LastUpdated (LastUpdated)
);

#
# Table structure for table 'AlumniLog'
#
CREATE TABLE AlumniLog (
  AlumniLogID int(11) DEFAULT '0' NOT NULL auto_increment,
  Action varchar(20) DEFAULT '' NOT NULL,
  AlumID int(11) DEFAULT '0' NOT NULL,
  TimeStamp timestamp(14),
  PRIMARY KEY (AlumniLogID),
  KEY Action (Action),
  KEY AlumID (AlumID),
  KEY TimeStamp (TimeStamp)
);

#
# Table structure for table 'Occupations'
#
CREATE TABLE Occupations (
  OccupationID int(10) unsigned DEFAULT '0' NOT NULL auto_increment,
  ShortName varchar(10) DEFAULT '' NOT NULL,
  Description varchar(50),
  PRIMARY KEY (OccupationID),
  KEY ShortName (ShortName),
  UNIQUE ShortName_2 (ShortName)
);

#
# Table structure for table 'Schools'
#
CREATE TABLE Schools (
  SchoolID int(10) unsigned DEFAULT '0' NOT NULL auto_increment,
  ShortName varchar(15) DEFAULT '' NOT NULL,
  LongName varchar(60),
  Abbreviation varchar(10),
  Approved tinyint(1) unsigned DEFAULT '0' NOT NULL,
  PRIMARY KEY (SchoolID),
  KEY Approved (Approved),
  KEY ShortName (ShortName),
  UNIQUE ShortName_2 (ShortName)
);

#
# Table structure for table 'SchoolLog'
#
CREATE TABLE SchoolLog (
  SchoolLogID int(11) DEFAULT '0' NOT NULL auto_increment,
  Action varchar(20) DEFAULT '' NOT NULL,
  SchoolID int(11) DEFAULT '0' NOT NULL,
  TimeStamp timestamp(14),
  PRIMARY KEY (SchoolLogID),
  KEY Action (Action),
  KEY SchoolID (SchoolID),
  KEY TimeStamp (TimeStamp)
);

